aboutsummaryrefslogtreecommitdiffstats
path: root/railties/test
diff options
context:
space:
mode:
authorTrevor Turk <trevorturk@gmail.com>2013-04-02 18:41:57 -0500
committerTrevor Turk <trevorturk@gmail.com>2013-04-02 18:41:57 -0500
commit7c7a42734406c4f1d402d32ff0b1b916545d0da0 (patch)
treeba62c423748bb0a606a785e6d558999e55718af0 /railties/test
parentc959798571b4060b19712e022f4236d75b2b7cfd (diff)
downloadrails-7c7a42734406c4f1d402d32ff0b1b916545d0da0.tar.gz
rails-7c7a42734406c4f1d402d32ff0b1b916545d0da0.tar.bz2
rails-7c7a42734406c4f1d402d32ff0b1b916545d0da0.zip
Rename DummyKeyGenerator -> LegacyKeyGenerator
Diffstat (limited to 'railties/test')
-rw-r--r--railties/test/application/middleware/remote_ip_test.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/railties/test/application/middleware/remote_ip_test.rb b/railties/test/application/middleware/remote_ip_test.rb
index f0d3438aa4..c655384d75 100644
--- a/railties/test/application/middleware/remote_ip_test.rb
+++ b/railties/test/application/middleware/remote_ip_test.rb
@@ -1,5 +1,5 @@
require 'isolation/abstract_unit'
# FIXME remove DummyKeyGenerator and this require in 4.1
require 'active_support/key_generator'
module ApplicationTests
@@ -10,7 +10,7 @@ module ApplicationTests
remote_ip = nil
env = Rack::MockRequest.env_for("/").merge(env).merge!(
'action_dispatch.show_exceptions' => false,
- 'action_dispatch.key_generator' => ActiveSupport::DummyKeyGenerator.new('b3c631c314c0bbca50c1b2843150fe33')
+ 'action_dispatch.key_generator' => ActiveSupport::LegacyKeyGenerator.new('b3c631c314c0bbca50c1b2843150fe33')
)
endpoint = Proc.new do |e|
@@ -1,5 +1,5 @@
require 'isolation/abstract_unit'
-# FIXME remove DummyKeyGenerator and this require in 4.1
+# FIXME remove LegacyKeyGenerator and this require in 4.1
require 'active_support/key_generator'
module ApplicationTests